# Copyright (c) 2007
# 	Riverbank Computing Limited <info@riverbankcomputing.co.uk>
# 
# This file is part of PyTQt.
# 
# This copy of PyTQt is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2, or (at your option) any later
# version.
# 
# PyTQt is supplied in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
# 
# You should have received a copy of the GNU General Public License along with
# PyTQt; see the file LICENSE.  If not, write to the Free Software Foundation,
# Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#
# This module is intended to be used by the configuration scripts of extension
# modules that %Import PyTQt modules.


import sip_tqt_config


# These are installation specific values created when PyTQt was configured.
_pkg_config = {
    '_pytqt_tqscintilla_defines':  '',
    '_pytqt_tqscintilla_inc_dir':  '/usr/include/tqt3',
    '_pytqt_tqscintilla_lib_dir':  '/usr/lib/x86_64-linux-gnu',
    'pytqt_bin_dir':               '/usr/bin',
    'pytqt_config_args':           '-c -n /usr/include/tqt3 -o /usr/lib/x86_64-linux-gnu -u -j 40 -d /usr/lib/python3.9/dist-packages/PyTQt -l /usr/include/python3.9 -v /usr/share/sip-tqt/tqt -m /usr/lib/python3.9/config -z CXXFLAGS_RELEASE= CXXFLAGS=-O1 -I/usr/include/tqt STRIP=',
    'pytqt_mod_dir':               '/usr/lib/python3.9/dist-packages/PyTQt',
    'pytqt_modules':               'tqt tqtcanvas tqtnetwork tqttable tqtxml tqtgl tqtui tqtsql tqtext',
    'pytqt_sip_dir':               '/usr/share/sip-tqt/tqt',
    'pytqt_tqt_sip_flags':         '-x TQt_STYLE_WINDOWSXP -x TQt_STYLE_INTERLACE -x TQt_STYLE_WINDOWSXP -x TQt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t TQt_3_3_6',
    'pytqt_tqtcanvas_sip_flags':   '-x TQt_STYLE_WINDOWSXP -x TQt_STYLE_INTERLACE -x TQt_STYLE_WINDOWSXP -x TQt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t TQt_3_3_6',
    'pytqt_tqtext_sip_flags':      '-x TQt_STYLE_WINDOWSXP -x TQt_STYLE_INTERLACE -x TQt_STYLE_WINDOWSXP -x TQt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t TQt_3_3_6 -t TQScintilla_1_7',
    'pytqt_tqtgl_sip_flags':       '-x TQt_STYLE_WINDOWSXP -x TQt_STYLE_INTERLACE -x TQt_STYLE_WINDOWSXP -x TQt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t TQt_3_3_6',
    'pytqt_tqtnetwork_sip_flags':  '-x TQt_STYLE_WINDOWSXP -x TQt_STYLE_INTERLACE -x TQt_STYLE_WINDOWSXP -x TQt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t TQt_3_3_6',
    'pytqt_tqttable_sip_flags':    '-x TQt_STYLE_WINDOWSXP -x TQt_STYLE_INTERLACE -x TQt_STYLE_WINDOWSXP -x TQt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t TQt_3_3_6',
    'pytqt_tqtui_sip_flags':       '-x TQt_STYLE_WINDOWSXP -x TQt_STYLE_INTERLACE -x TQt_STYLE_WINDOWSXP -x TQt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t TQt_3_3_6',
    'pytqt_tqtxml_sip_flags':      '-x TQt_STYLE_WINDOWSXP -x TQt_STYLE_INTERLACE -x TQt_STYLE_WINDOWSXP -x TQt_SIP_PRE_4_7_2 -x VendorID -t WS_X11 -t TQt_3_3_6',
    'pytqt_version':               0x031201,
    'pytqt_version_str':           '3.18.1',
    'tqt_dir':                     '/usr/share/tqt3',
    'tqt_edition':                 'free',
    'tqt_framework':               0,
    'tqt_inc_dir':                 '/usr/share/tqt3/include',
    'tqt_lib':                     'tqt-mt',
    'tqt_lib_dir':                 '/usr/share/tqt3/lib',
    'tqt_threaded':                1,
    'tqt_version':                 0x030500,
    'tqt_winconfig':               ''
}

_default_macros = {
    'AIX_SHLIB':                '',
    'AR':                       'ar cqs',
    'CC':                       'gcc',
    'CFLAGS':                   '-pipe -g -fvisibility=hidden',
    'CFLAGS_CONSOLE':           '',
    'CFLAGS_DEBUG':             '-O0',
    'CFLAGS_EXCEPTIONS_OFF':    '',
    'CFLAGS_EXCEPTIONS_ON':     '',
    'CFLAGS_MT':                '',
    'CFLAGS_MT_DBG':            '',
    'CFLAGS_MT_DLL':            '',
    'CFLAGS_MT_DLLDBG':         '',
    'CFLAGS_RELEASE':           '-O2',
    'CFLAGS_RTTI_OFF':          '',
    'CFLAGS_RTTI_ON':           '',
    'CFLAGS_SHLIB':             '-fPIC',
    'CFLAGS_STL_OFF':           '',
    'CFLAGS_STL_ON':            '',
    'CFLAGS_THREAD':            '-D_REENTRANT',
    'CFLAGS_WARN_OFF':          '-w',
    'CFLAGS_WARN_ON':           '-Wall -W',
    'CHK_DIR_EXISTS':           'test -d',
    'CONFIG':                   'qt warn_on release incremental link_prl thread',
    'COPY':                     'cp -f',
    'CXX':                      'g++',
    'CXXFLAGS':                 '-O1 -I/usr/include/tqt',
    'CXXFLAGS_CONSOLE':         '',
    'CXXFLAGS_DEBUG':           '-O0',
    'CXXFLAGS_EXCEPTIONS_OFF':  '',
    'CXXFLAGS_EXCEPTIONS_ON':   '',
    'CXXFLAGS_MT':              '',
    'CXXFLAGS_MT_DBG':          '',
    'CXXFLAGS_MT_DLL':          '',
    'CXXFLAGS_MT_DLLDBG':       '',
    'CXXFLAGS_RELEASE':         '',
    'CXXFLAGS_RTTI_OFF':        '',
    'CXXFLAGS_RTTI_ON':         '',
    'CXXFLAGS_SHLIB':           '-fPIC',
    'CXXFLAGS_STL_OFF':         '',
    'CXXFLAGS_STL_ON':          '',
    'CXXFLAGS_THREAD':          '-D_REENTRANT',
    'CXXFLAGS_WARN_OFF':        '-w',
    'CXXFLAGS_WARN_ON':         '-Wall -W',
    'DEFINES':                  '',
    'DEL_FILE':                 'rm -f',
    'EXTENSION_PLUGIN':         '',
    'EXTENSION_SHLIB':          '',
    'INCDIR':                   '',
    'INCDIR_OPENGL':            '/usr/X11R6/include',
    'INCDIR_TQT':               '/usr/share/tqt3/include',
    'INCDIR_X11':               '/usr/X11R6/include',
    'LFLAGS':                   '-luuid',
    'LFLAGS_CONSOLE':           '',
    'LFLAGS_CONSOLE_DLL':       '',
    'LFLAGS_DEBUG':             '',
    'LFLAGS_DLL':               '',
    'LFLAGS_OPENGL':            '',
    'LFLAGS_PLUGIN':            '-shared',
    'LFLAGS_RELEASE':           '',
    'LFLAGS_SHLIB':             '-shared',
    'LFLAGS_SONAME':            '-Wl,-soname,',
    'LFLAGS_THREAD':            '',
    'LFLAGS_WINDOWS':           '',
    'LFLAGS_WINDOWS_DLL':       '',
    'LIB':                      '',
    'LIBDIR':                   '',
    'LIBDIR_OPENGL':            '/usr/X11R6/lib',
    'LIBDIR_TQT':               '/usr/share/tqt3/lib',
    'LIBDIR_X11':               '/usr/X11R6/lib',
    'LIBS':                     '-luuid',
    'LIBS_CONSOLE':             '',
    'LIBS_CORE':                '',
    'LIBS_GUI':                 '',
    'LIBS_NETWORK':             '',
    'LIBS_OPENGL':              '-lGLU -lGL -lXmu',
    'LIBS_RT':                  '',
    'LIBS_RTMT':                '',
    'LIBS_THREAD':              '-lpthread',
    'LIBS_WEBKIT':              '',
    'LIBS_WINDOWS':             '',
    'LIBS_X11':                 '-lXext -lX11 -lm',
    'LINK':                     'g++',
    'LINK_SHLIB':               'g++',
    'LINK_SHLIB_CMD':           '',
    'MAKEFILE_GENERATOR':       'UNIX',
    'MKDIR':                    'mkdir -p',
    'MOC':                      '/usr/share/tqt3/bin/tqmoc',
    'RANLIB':                   '',
    'RPATH':                    '',
    'STRIP':                    ''
}


class Configuration(sip_tqt_config.Configuration):
    """The class that represents PyTQt configuration values.
    """
    def __init__(self, sub_cfg=None):
        """Initialise an instance of the class.

        sub_cfg is the list of sub-class configurations.  It should be None
        when called normally.
        """
        if sub_cfg:
            cfg = sub_cfg
        else:
            cfg = []

        cfg.append(_pkg_config)

        sip_tqt_config.Configuration.__init__(self, cfg)


class TQtModuleMakefile(sip_tqt_config.SIPModuleMakefile):
    """The Makefile class for modules that %Import tqt.
    """
    def __init__(self, *args, **kw):
        """Initialise an instance of a module Makefile.
        """
        kw["tqt"] = 1
        apply(sip_tqt_config.SIPModuleMakefile.__init__, (self, ) + args, kw)

    def finalise(self):
        """Finalise the macros.
        """
        if self.config.sip_version < 0x040000:
            # Note that we don't use self.extra_lib_dirs because we don't want
            # it to be added to the rpath.
            self.LIBDIR.append(self.config.pytqt_mod_dir)
            self.extra_libs.append(self.module_as_lib("tqt"))

        sip_tqt_config.SIPModuleMakefile.finalise(self)


class TQtAxContainerModuleMakefile(TQtModuleMakefile):
    """The Makefile class for modules that %Import tqtaxcontainer.
    """
    def finalise(self):
        """Finalise the macros.
        """
        if self.config.sip_version < 0x040000:
            self.extra_libs.append(self.module_as_lib("tqtaxcontainer"))

        TQtModuleMakefile.finalise(self)


class TQtCanvasModuleMakefile(TQtModuleMakefile):
    """The Makefile class for modules that %Import tqtcanvas.
    """
    def finalise(self):
        """Finalise the macros.
        """
        if self.config.sip_version < 0x040000:
            self.extra_libs.append(self.module_as_lib("tqtcanvas"))

        TQtModuleMakefile.finalise(self)


class TQtExtModuleMakefile(TQtModuleMakefile):
    """The Makefile class for modules that %Import tqtext.
    """
    def finalise(self):
        """Finalise the macros.
        """
        if self.config.sip_version < 0x040000:
            self.extra_libs.append(self.module_as_lib("tqtext"))

        self.extra_defines.extend(self.config._pytqt_tqscintilla_defines)
        self.extra_include_dirs.append(self.config._pytqt_tqscintilla_inc_dir)
        self.extra_lib_dirs.append(self.config._pytqt_tqscintilla_lib_dir)
        self.extra_libs.append("tqscintilla")

        TQtModuleMakefile.finalise(self)


class TQtGLModuleMakefile(TQtModuleMakefile):
    """The Makefile class for modules that %Import tqtgl.
    """
    def __init__(self, *args, **kw):
        """Initialise an instance of a module Makefile.
        """
        kw["opengl"] = 1
        apply(TQtModuleMakefile.__init__, (self, ) + args, kw)

    def finalise(self):
        """Finalise the macros.
        """
        if self.config.sip_version < 0x040000:
            self.extra_libs.append(self.module_as_lib("tqtgl"))

        TQtModuleMakefile.finalise(self)


class TQtNetworkModuleMakefile(TQtModuleMakefile):
    """The Makefile class for modules that %Import tqtnetwork.
    """
    def finalise(self):
        """Finalise the macros.
        """
        if self.config.sip_version < 0x040000:
            self.extra_libs.append(self.module_as_lib("tqtnetwork"))

        TQtModuleMakefile.finalise(self)


class TQtTableModuleMakefile(TQtModuleMakefile):
    """The Makefile class for modules that %Import tqttable.
    """
    def finalise(self):
        """Finalise the macros.
        """
        if self.config.sip_version < 0x040000:
            self.extra_libs.append(self.module_as_lib("tqttable"))

        TQtModuleMakefile.finalise(self)


class TQtSQLModuleMakefile(TQtTableModuleMakefile):
    """The Makefile class for modules that %Import tqtsql.
    """
    def finalise(self):
        """Finalise the macros.
        """
        if self.config.sip_version < 0x040000:
            self.extra_libs.append(self.module_as_lib("tqtsql"))

        TQtTableModuleMakefile.finalise(self)


class TQtUIModuleMakefile(TQtModuleMakefile):
    """The Makefile class for modules that %Import tqtui.
    """
    def finalise(self):
        """Finalise the macros.
        """
        if self.config.sip_version < 0x040000:
            self.extra_libs.append(self.module_as_lib("tqtui"))

        TQtModuleMakefile.finalise(self)


class TQtXMLModuleMakefile(TQtModuleMakefile):
    """The Makefile class for modules that %Import tqtxml.
    """
    def finalise(self):
        """Finalise the macros.
        """
        if self.config.sip_version < 0x040000:
            self.extra_libs.append(self.module_as_lib("tqtxml"))

        TQtModuleMakefile.finalise(self)
